Convert precision matrix to partial correlation matrix
precision_to_pcor.RdGiven a precision matrix \(\Omega\), returns the partial correlation matrix
\(P\) with entries \(P_{ij} = -\Omega_{ij}/\sqrt{\Omega_{ii}\,\Omega_{jj}}\)
and ones on the diagonal. Partial correlations measure the linear association
between variables i and j after conditioning on all other
variables.
Value
A symmetric numeric matrix of the same dimension as Omega,
with diagonal entries equal to 1 and off-diagonal entries in [-1, 1].